@@ -50,8 +50,6 @@ struct auto_response {
   time_t time_sent;
 };
 
-static struct away_message *awaymessage_tmp = NULL;
-
 static GList *auto_recepients = NULL;
 
 /* Commands */
@@ -65,13 +63,30 @@ static GaimCmdRet cmd_back_cb (GaimConversation *, const gchar *, gchar **,
 /*--------------------------------------------------------------------------
  * REQUIRED GAIM FUNCTIONS- INFO, INITIALIZATION, UNLOADING
  *------------------------------------------------------------------------*/
+void queue_cb (
+  const char *name, GaimPrefType type, gconstpointer val, gpointer data) {
+  if (is_away) {
+    if (gaim_prefs_get_bool("/plugins/gtk/autoprofile/queue_messages_when_away")) {
+      gaim_prefs_set_string ("/gaim/gtk/conversations/im/hide_new", "away");
+    } else {
+      gaim_prefs_set_string ("/gaim/gtk/conversations/im/hide_new", "never");
+    }
+  }
+}
+
 /* What to do when plugin is loaded */
 static gboolean plugin_load (GaimPlugin *plugin)
 {
   int interval;
   GList *comp_list;
   struct component *comp;
-  
+ 
+  /* TODO: This should go into a gtk_load or something like that */
+  gaim_prefs_connect_callback (
+    plugin_handle, 
+    "/plugins/gtk/autoprofile/queue_messages_when_away", queue_cb, NULL);
+
+ 
   /* Initialize variables */
   components = get_components ();
   is_away = FALSE;
@@ -194,13 +209,13 @@ char *autoprofile_generate (const char *format) {
   int state;
 
   /* Set up strings */
-  output = (char *)malloc (1024);
+  output = (char *)malloc (sizeof(char) * AP_SIZE_MAXIMUM);
   *output = '\0';
   single_char = (char *)malloc(2);
   *(single_char + 1) = '\0';
   *single_char = 'a';
 
-  space_left = 1023;
+  space_left = AP_SIZE_MAXIMUM - 1;
 
   /* When previous char was a %, state is 1, otherwise 0 */
   state = 0;
@@ -310,6 +325,12 @@ gboolean status_away ()
   int interval;
   GaimAccount *current;
 
+  if (gaim_prefs_get_bool ("/plugins/gtk/autoprofile/queue_messages_when_away")) {
+    gaim_prefs_set_string ("/gaim/gtk/conversations/im/hide_new", "away");
+  } else {
+    gaim_prefs_set_string ("/gaim/gtk/conversations/im/hide_new", "never");
+  }
+
   /* Make sure at least one account is activated */
   accounts = gaim_accounts_get_all ();
 
@@ -360,6 +381,8 @@ void status_back ()
   GList *tmp;
   struct auto_response *p;
 
+  gaim_prefs_set_string ("/gaim/gtk/conversations/im/hide_new", "never");
+
   is_away = FALSE;
   gaim_prefs_set_int ("/plugins/gtk/autoprofile/current_away", -1);
 
@@ -517,7 +540,7 @@ gboolean away_update (gpointer data)
   GList *start_node, *cur_node;
 
   /* Get all accounts and search through each */
-  GList *gaim_accounts = gaim_accounts_get_all ();
+  GList *gaim_accounts = gaim_accounts_get_all_active ();
 
   if (is_away) {
 
@@ -552,13 +575,6 @@ gboolean away_update (gpointer data)
     text = NULL;
   }
 
-  /* Avoid conflicts with regular Gaim away messages */
-  do_im_back (NULL, NULL);
-  awayqueue = NULL;
-  if (awayqueuestore != NULL)
-    g_object_unref (G_OBJECT (awayqueuestore));
-  awayqueuestore = NULL;
-
   auto_debug ("away", "updating away messages");
 
   while (gaim_accounts) {
@@ -568,28 +584,25 @@ gboolean away_update (gpointer data)
 
     /* Check to see if update option set on account */
     if (away_bool) {
-      if (gaim_account_is_connected (account)) {
-        GaimConnection *gc = gaim_account_get_connection (account);
-        serv_set_away (gc, GAIM_AWAY_CUSTOM, text);
+        if (text != NULL) {
+          GaimSavedStatus *saved_status = gaim_savedstatus_new (
+            NULL, GAIM_STATUS_AWAY);
+          gaim_savedstatus_set_message (saved_status, text);
+          gaim_savedstatus_activate_for_account (saved_status, account);
+        } else {
+          GaimSavedStatus *saved_status = gaim_savedstatus_new (
+            NULL, GAIM_STATUS_AVAILABLE);
+          gaim_savedstatus_activate_for_account (saved_status, account);
+        }
+
 	      activated = TRUE;
-      } else {
-        auto_debug ("away", "account not online, skipping");
-      }
     } 
     gaim_accounts = gaim_accounts->next;
   }
 
   if (is_away && activated) {
     gtk_away_msgs_create (text);
-    if (!awaymessage_tmp)
-      awaymessage_tmp = (struct away_message *)malloc (
-        sizeof(struct away_message));
-    awaymessage = awaymessage_tmp;
   } else {
-    if (awaymessage_tmp)
-      free (awaymessage_tmp);
-    awaymessage_tmp = NULL;  
-    awaymessage = NULL;
     gtk_away_msgs_destroy ();
   }
 
@@ -598,120 +611,6 @@ gboolean away_update (gpointer data)
   return TRUE;
 }
 
-/*----------------------------- Auto-responder -------------------------*/
-static void write_autoresponse (GaimAccount *account, char *sender,
-                                char *msg)
-{
-  GaimConversation *conv;
-  GaimConvIm *conv_im;
-  
-  conv = gaim_find_conversation_with_account (sender, account);
-  if (conv) {
-    conv_im = gaim_conversation_get_im_data (conv);
-    gaim_conv_im_write (conv_im, sender, msg, 
-      GAIM_CONV_IM_AUTO_RESP, time (NULL));
-  } else {
-
-  }
-}
-
-void regular_received (GaimAccount *account, char *sender,
-                       char *message, int flags) 
-{
-  GaimConnection *gc;
-  GList *recepients, *msg_node, *start_node;
-  struct auto_response *p;
-  int away_num;
-  char *text_respond, *generated, *text;
-
-  /* State checking */
-  if (!is_away || !original_autoresponse || sending_auto)
-    return;
-
-  if (!get_account_boolean(account, _("enable_away")))
-    return;
-
-  away_num = gaim_prefs_get_int (
-    "/plugins/gtk/autoprofile/current_away");
-  if (away_num < 0) {
-    auto_debug ("auto-response", "no away msg has been set");
-    return;
-  }
-
-  /* Getting vars that will be used */
-  gc = gaim_account_get_connection (account);
-  sending_auto = TRUE;
-
-  msg_node = gaim_prefs_get_string_list (
-    "/plugins/gtk/autoprofile/message_texts");
-  start_node = msg_node;
-  while (away_num-- != 0) {
-    msg_node = msg_node->next;
-  }
-  
-  text_respond = stylize (gaim_prefs_get_string (
-    "/plugins/gtk/autoprofile/text_respond"), 1000);
-  generated = autoprofile_generate ((char *)msg_node->data);
-  free_string_list (start_node);
-
-  recepients = auto_recepients;
-  while (recepients) {
-    p = (struct auto_response *)recepients->data;
-    if (!strcmp (sender, p->recepient) &&
-        p->account == account)
-      break;
-    recepients = recepients->next;
-  }
-
-  if (recepients == NULL) {
-    /* New conversation */
-    serv_send_im (gc, sender, generated, GAIM_CONV_IM_AUTO_RESP);
-    write_autoresponse (account, sender, generated);
-    if (gaim_prefs_get_bool ("/plugins/gtk/autoprofile/use_trigger")) {
-      write_autoresponse (account, sender, text_respond);
-      serv_send_im (gc, sender, text_respond, GAIM_CONV_IM_AUTO_RESP);
-    }
-
-    p = (struct auto_response *)malloc (sizeof(struct auto_response));
-    p->account = account;
-    p->recepient = strdup (sender);
-    p->time_sent = time (NULL);
-    recepients = (GList *)malloc (sizeof (GList));
-    recepients->data = p;
-    recepients->next = auto_recepients;
-    auto_recepients = recepients;
-  } else {
-    p = (struct auto_response *)recepients->data;
-    if ((int)difftime (time (NULL), p->time_sent) > 180) {
-      /* Conversation exists, but old */
-      serv_send_im (gc, sender, generated, GAIM_CONV_IM_AUTO_RESP);
-      write_autoresponse (account, sender, generated);
-      if (gaim_prefs_get_bool ("/plugins/gtk/autoprofile/use_trigger")) {
-        write_autoresponse (account, sender, text_respond);
-        serv_send_im (gc, sender, text_respond, GAIM_CONV_IM_AUTO_RESP);
-      }
-      p->time_sent = time (NULL);
-    } else {
-      /* Conversation exists, recent enough to semi-ignore */
-      if (difftime (time(NULL), response_timeout) >
-          gaim_prefs_get_int ("/plugins/gtk/autoprofile/delay_respond")) {
-        text = gaim_markup_strip_html (message);
-        if (match_start (text, (char *)gaim_prefs_get_string (
-                         "/plugins/gtk/autoprofile/text_trigger")) == 1) {
-          write_autoresponse (account, sender, generated);
-          serv_send_im (gc, sender, generated, GAIM_CONV_IM_AUTO_RESP);
-          response_timeout = time (NULL);
-          auto_debug ("autorespond", "string matched, responding");
-        }
-        free (text);
-      }
-    }
-  }
-  free (generated);                     
-  free (text_respond);
-  sending_auto = FALSE;                       
-}
-
 /*--------------------------------------------------------------------------
  * LAST CALL                                               
  *------------------------------------------------------------------------*/
