@@ -608,7 +608,7 @@ static char *date_string (const char *field)
   if (!d)
     return NULL;
 
-  output = (char *)malloc (1024);
+  output = (char *)malloc (sizeof(char) * AP_SIZE_MAXIMUM);
   t_struct = (struct tm *)malloc(sizeof(struct tm));
   t_struct->tm_year = d->year;
   t_struct->tm_mon = d->month;
@@ -620,7 +620,7 @@ static char *date_string (const char *field)
   free (t_struct);
   t_struct = localtime (&t);
 
-  strftime (output, 1000, "%a %b %d, %Y", t_struct);
+  strftime (output, AP_SIZE_MAXIMUM - 1, "%a %b %d, %Y", t_struct);
   return output; 
 }
 
@@ -677,7 +677,7 @@ static void logstats_conv_created (GaimConversation *conv)
   struct log_date *the_date;
   struct conversation_time *the_time;
   
-  if (conv->type == GAIM_CONV_IM) {
+  if (conv->type == GAIM_CONV_TYPE_IM) {
     the_time = malloc (sizeof(struct conversation_time));
     the_time->name = strdup (conv->name);
     the_time->start_time = malloc (sizeof(time_t));
@@ -710,24 +710,24 @@ void logstats_load ()
   logstats_update_dates ();
 
   /* Debug */
-  msg = (char *)malloc (1000);
+  msg = (char *)malloc (sizeof(char) * AP_SIZE_MAXIMUM);
   count = get_total ("received_msgs");
-  g_snprintf (msg, 1000, "received msg total is %d", count);
+  g_snprintf (msg, AP_SIZE_MAXIMUM, "received msg total is %d", count);
   auto_debug ("logstats", msg);
   count = get_total ("sent_msgs");
-  g_snprintf (msg, 1000, "sent msg total is %d", count);
+  g_snprintf (msg, AP_SIZE_MAXIMUM, "sent msg total is %d", count);
   auto_debug ("logstats", msg);
   count = get_total ("received_words");
-  g_snprintf (msg, 1000, "received word total is %d", count);
+  g_snprintf (msg, AP_SIZE_MAXIMUM, "received word total is %d", count);
   auto_debug ("logstats", msg);
   count = get_total ("sent_words");
-  g_snprintf (msg, 1000, "sent word total is %d", count);
+  g_snprintf (msg, AP_SIZE_MAXIMUM, "sent word total is %d", count);
   auto_debug ("logstats", msg);
   count = get_total ("num_convos");
-  g_snprintf (msg, 1000, "num conversations is %d", count);
+  g_snprintf (msg, AP_SIZE_MAXIMUM, "num conversations is %d", count);
   auto_debug ("logstats", msg);
   count = g_slist_length (dates);
-  g_snprintf (msg, 1000, "num days with conversations is %d", count);
+  g_snprintf (msg, AP_SIZE_MAXIMUM, "num days with conversations is %d", count);
   auto_debug ("logstats", msg);
 
   free(msg);
@@ -814,9 +814,9 @@ static char *logstats_generate ()
   format = gaim_prefs_get_string (
     "/plugins/gtk/autoprofile/components/logstat/format");
 
-  output = (char *)malloc (1024);
+  output = (char *)malloc (sizeof(char)*AP_SIZE_MAXIMUM);
   *output = '\0';
-  buf = (char *)malloc (1024);
+  buf = (char *)malloc (sizeof(char)*AP_SIZE_MAXIMUM);
   *buf = '\0';
 
   state = 0;
@@ -825,162 +825,162 @@ static char *logstats_generate ()
     if (state == 1) {
       switch (*format) {
         case '%':
-          g_snprintf (buf, 1000, "%s%c", output, *format);
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%c", output, *format);
           break;
         case 'R':
-          g_snprintf (buf, 1000, "%s%d", output, get_total ("received_msgs"));
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output, get_total ("received_msgs"));
           break;
         case 'r':
-          g_snprintf (buf, 1000, "%s%d", output, get_total ("received_words"));
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output, get_total ("received_words"));
           break;
         case 'S':
-          g_snprintf (buf, 1000, "%s%d", output, get_total ("sent_msgs"));
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output, get_total ("sent_msgs"));
           break;
         case 's':
-          g_snprintf (buf, 1000, "%s%d", output, get_total ("sent_words"));
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output, get_total ("sent_words"));
           break;
         case 'T':
-          g_snprintf (buf, 1000, "%s%d", output, 
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output, 
             get_total ("sent_msgs") + get_total ("received_msgs"));
           break;
         case 't':
-          g_snprintf (buf, 1000, "%s%d", output, 
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output, 
             get_total ("sent_words") + get_total ("received_words"));
           break;
         case 'D':
-          g_snprintf (buf, 1000, "%s%d", output,
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output,
             num_days_since_start ());
           break;
         case 'd':
-          g_snprintf (buf, 1000, "%s%d", output, g_slist_length (dates));
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output, g_slist_length (dates));
           break;
         case 'N':
-          g_snprintf (buf, 1000, "%s%d", output, get_total ("num_convos"));
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output, get_total ("num_convos"));
           break;
         case 'n':
-          g_snprintf (buf, 1000, "%s%.2f", output,
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%.2f", output,
             (double) get_total ("num_convos") / (double) g_slist_length (dates));
           break;
         case 'i':
-          g_snprintf (buf, 1000, "%s%d", output, get_max ("conversations"));
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output, get_max ("conversations"));
           break;
         case 'I':
           date = date_string ("conversations");
-          g_snprintf (buf, 1000, "%s%s", output, date);
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%s", output, date);
           free (date);
           break;
         case 'j':
-          g_snprintf (buf, 1000, "%s%d", output, get_max ("sent"));
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output, get_max ("sent"));
           break;
         case 'J':
           date = date_string ("sent");
-          g_snprintf (buf, 1000, "%s%s", output, date);
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%s", output, date);
           free (date);
           break;
         case 'k':
-          g_snprintf (buf, 1000, "%s%d", output, get_max ("received"));
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output, get_max ("received"));
           break;
         case 'K':
           date = date_string ("received");
-          g_snprintf (buf, 1000, "%s%s", output, date);
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%s", output, date);
           free (date);
           break;
         case 'l':
-          g_snprintf (buf, 1000, "%s%d", output, get_max ("total"));
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output, get_max ("total"));
           break;
         case 'L':
           date = date_string ("total");
-          g_snprintf (buf, 1000, "%s%s", output, date);
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%s", output, date);
           free (date);
           break;
         case 'f':
           date = date_string ("first");
-          g_snprintf (buf, 1000, "%s%s", output, date);
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%s", output, date);
           free (date);
           break;
         case 'u':
-          g_snprintf (buf, 1000, "%s%.2f", output, 
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%.2f", output, 
             (double) get_total ("received_words") / (double) get_total ("received_msgs"));
           break;
         case 'v':
-          g_snprintf (buf, 1000, "%s%.2f", output, 
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%.2f", output, 
             (double) get_total ("sent_words") / (double) get_total ("sent_msgs"));
           break;
         case 'w':
-          g_snprintf (buf, 1000, "%s%.2f", output, 
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%.2f", output, 
             (double) (get_total ("received_words") + get_total ("sent_words")) / (double) (get_total("received_msgs") + get_total ("sent_msgs")));
           break;
         case 'U':
-         g_snprintf (buf, 1000, "%s%.2f", output, 
+         g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%.2f", output, 
             (double) get_total ("received_msgs") / (double) get_total ("num_convos"));
           break;
         case 'V':
-         g_snprintf (buf, 1000, "%s%.2f", output, 
+         g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%.2f", output, 
             (double) get_total ("sent_msgs") / (double) get_total ("num_convos"));
           break;
         case 'W':
-         g_snprintf (buf, 1000, "%s%.2f", output, 
+         g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%.2f", output, 
             (double) (get_total ("received_msgs") + get_total ("sent_msgs")) / (double) get_total("num_convos"));
           break;
         case 'x':
-         g_snprintf (buf, 1000, "%s%.2f", output, 
+         g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%.2f", output, 
             (double) get_total ("received_words") / (double) g_slist_length (dates));
           break;
         case 'y':
-         g_snprintf (buf, 1000, "%s%.2f", output, 
+         g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%.2f", output, 
             (double) get_total ("sent_words") / (double) g_slist_length (dates));
           break;
         case 'z':
-         g_snprintf (buf, 1000, "%s%.2f", output, 
+         g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%.2f", output, 
             ((double) get_total ("received_words") + (double) get_total ("sent_words")) / (double) g_slist_length (dates));
           break;
         case 'X':
-         g_snprintf (buf, 1000, "%s%.2f", output, 
+         g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%.2f", output, 
             (double) get_total ("received_msgs") / (double) g_slist_length (dates));
           break;
         case 'Y':
-          g_snprintf (buf, 1000, "%s%.2f", output, 
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%.2f", output, 
             (double) get_total ("sent_msgs") / (double) g_slist_length (dates));
           break;
         case 'Z':
-          g_snprintf (buf, 1000, "%s%.2f", output, 
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%.2f", output, 
             (double) (get_total ("received_msgs") + get_total ("sent_msgs")) / (double) g_slist_length (dates));
           break;
         case 'p':
-          g_snprintf (buf, 1000, "%s%.1f", output,
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%.1f", output,
             100.0 * (double) g_slist_length (dates) / (double) num_days_since_start ());
           break;
         case 'a':
-          g_snprintf (buf, 1000, "%s%d", output,
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output,
             ((struct log_date *) dates->data)->received_msgs);
           break;
         case 'b':
-          g_snprintf (buf, 1000, "%s%d", output,
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output,
             ((struct log_date *) dates->data)->sent_msgs);
           break;
         case 'c':
-          g_snprintf (buf, 1000, "%s%d", output,
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output,
             g_slist_length (((struct log_date *) dates->data)->conversation_times));
           break;
         case 'e':
-          g_snprintf (buf, 1000, "%s%d", output,
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output,
             ((struct log_date *) dates->data)->sent_msgs + ((struct log_date *) dates->data)->received_msgs);
           break;
         case 'A':
-          g_snprintf (buf, 1000, "%s%d", output, get_recent_total ("received_msgs", 24 * 7));
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output, get_recent_total ("received_msgs", 24 * 7));
           break;
         case 'B':
-          g_snprintf (buf, 1000, "%s%d", output, get_recent_total ("sent_msgs", 24 * 7));
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output, get_recent_total ("sent_msgs", 24 * 7));
           break;
         case 'C':
-          g_snprintf (buf, 1000, "%s%d", output, get_recent_total ("num_convos", 24 * 7));
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output, get_recent_total ("num_convos", 24 * 7));
           break;
         case 'E':
-          g_snprintf (buf, 1000, "%s%d", output, 
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%d", output, 
             get_recent_total ("received_msgs", 24 * 7) + get_recent_total ("received_msgs", 24 * 7));
           break;
         default:
-          g_snprintf (buf, 1000, "%s%c", output, *format);
+          g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%c", output, *format);
           break;
       }
 
@@ -991,7 +991,7 @@ static char *logstats_generate ()
       if (*format == '%') {
         state = 1;
       } else {
-        g_snprintf (buf, 1000, "%s%c", output, *format);
+        g_snprintf (buf, AP_SIZE_MAXIMUM, "%s%c", output, *format);
         strcpy (output, buf);
       }
       format++;
