@@ -66,7 +66,7 @@ struct edit_message {
 
 /* Returns boolean in regards to account having option set for updates
  * and responses. */
-gboolean get_account_boolean (GaimAccount *account, char *value) 
+gboolean get_account_boolean (GaimAccount *account, const char *value) 
 {
   GList *accounts_list, *start_list;
 
@@ -462,18 +462,19 @@ static GtkWidget *get_config_frame (GaimPlugin *plugin)
 
 
   /*---------- Update frequency ----------*/
+/*
   frame = gaim_gtk_make_frame (page, _("Special auto-responses"));
   vbox = gtk_vbox_new (FALSE, 5);
   gtk_container_add (GTK_CONTAINER (frame), vbox);
 
-  /* Auto-response activated */
+  / Auto-response activated /
   checkbox = gaim_gtk_prefs_checkbox (
     _("Allow users to request more auto-responses"),
     "/plugins/gtk/autoprofile/use_trigger", vbox);
   large_vbox = gtk_vbox_new (FALSE, 5);
   gtk_box_pack_start (GTK_BOX (vbox), large_vbox, FALSE, FALSE, 0);
  
-  /* Auto-response delay */
+  / Auto-response delay /
   hbox = gtk_hbox_new (FALSE, 5);
   gtk_box_pack_start (GTK_BOX (large_vbox), hbox, FALSE, FALSE, 0);
   label = gtk_label_new (_("Delay"));
@@ -487,7 +488,7 @@ static GtkWidget *get_config_frame (GaimPlugin *plugin)
   g_signal_connect (G_OBJECT (spinner), "value-changed",
                     G_CALLBACK (update_delay_respond), NULL);
 
-  /* Auto-response trigger string */
+  / Auto-response trigger string /
   label = gtk_label_new (_(
     "Message sent to new conversation:"));
   gtk_box_pack_start (GTK_BOX (large_vbox), label, FALSE, FALSE, 0);
@@ -519,7 +520,7 @@ static GtkWidget *get_config_frame (GaimPlugin *plugin)
   } else {
     gtk_widget_set_sensitive (large_vbox, TRUE);
   }
-
+*/
   /*---------- Individual account settings ---------*/
   page = gtk_vbox_new (FALSE, 7);
   gtk_container_set_border_width (GTK_CONTAINER (page), 12);
@@ -1324,7 +1325,6 @@ static void gtk_edit_msg (char *title, char *message)
 
   /* Set up window */
   GAIM_DIALOG(ca->window);
-  gtk_widget_set_size_request(ca->window, -1, 250);
   gtk_container_set_border_width(GTK_CONTAINER(ca->window), 6);
   gtk_window_set_role(GTK_WINDOW(ca->window), "away_mess");
   gtk_window_set_title(GTK_WINDOW(ca->window), _("Edit message"));
@@ -1363,13 +1363,8 @@ static void gtk_edit_msg (char *title, char *message)
   ca->text = gtk_imhtml_new(NULL, NULL);
   gtk_imhtml_set_editable(GTK_IMHTML(ca->text), TRUE);
   gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(ca->text), GTK_WRAP_WORD_CHAR);
+  gtk_widget_set_size_request(ca->text, -1, 150);
 
-  gtk_imhtml_smiley_shortcuts(GTK_IMHTML(ca->text),
-    gaim_prefs_get_bool("/gaim/gtk/conversations/smiley_shortcuts"));
-  gtk_imhtml_html_shortcuts(GTK_IMHTML(ca->text),
-    gaim_prefs_get_bool("/gaim/gtk/conversations/html_shortcuts"));
-  if (gaim_prefs_get_bool("/gaim/gtk/conversations/spellcheck"))
-    gaim_gtk_setup_gtkspell(GTK_TEXT_VIEW(ca->text));
   gtk_imhtmltoolbar_attach(GTK_IMHTMLTOOLBAR(ca->toolbar), ca->text);
 
   gtk_container_add(GTK_CONTAINER(sw), ca->text);
@@ -1395,6 +1390,9 @@ static void gtk_edit_msg (char *title, char *message)
     G_CALLBACK(mess_destroy), ca);
   gtk_box_pack_end(GTK_BOX(hbox), button, FALSE, FALSE, 0);
 
+  label = gtk_label_new (_("Use shift+enter to insert a new line"));
+  gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+
   /* Display component options */
   vbox = gtk_vbox_new (FALSE, 5);
   gtk_box_pack_start (GTK_BOX(big_hbox), vbox, FALSE, FALSE, 0);
